==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sr.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Корак 1 није успео. Изузетак: %s",
    "Step 2 failed. Exception: %s" : "Корак 2 није успео. Изузетак: %s",
    "External storage" : "Спољашње складиште",
    "Storage with id \"%i\" not found" : "Складиште са идентификацијом \"%i\" није пронађено",
    "Invalid mount point" : "Неисправна тачка монтирања",
    "Invalid storage backend \"%s\"" : "Неисправна позадина складишта „%s“",
    "Personal" : "Лично",
    "System" : "Систем",
    "Grant access" : "Одобри приступ",
    "Access granted" : "Приступ одобрен",
    "Generate keys" : "Генериши кључеве",
    "Error generating key pair" : "Грешка при генерисању пара кључева",
    "Enable encryption" : "Укључи шифровање",
    "Enable previews" : "Укључи прегледе",
    "Check for changes" : "Провери измене",
    "Never" : "никад",
    "Once every direct access" : "једном при сваком директном приступу",
    "Every time the filesystem is used" : "сваки пут кад се фајл-систем користи",
    "All users. Type to select user or group." : "Сви корисници. Куцајте за избор корисника или групе.",
    "(group)" : "(група)",
    "Saved" : "Сачувано",
    "None" : "Ништа",
    "App key" : "Кључ апликације",
    "App secret" : "Тајна апликације",
    "Client ID" : "ИД клијента",
    "Client secret" : "Тајна клијента",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "API key" : "API кључ",
    "Public key" : "Јавни кључ",
    "Amazon S3" : "Амазон С3",
    "Bucket" : "Канта",
    "Hostname" : "Име домаћина",
    "Port" : "Порт",
    "Region" : "Регија",
    "Enable SSL" : "Омогући ССЛ",
    "Enable Path Style" : "Омогући стил путање",
    "WebDAV" : "ВебДАВ",
    "URL" : "УРЛ",
    "Remote subfolder" : "Удаљена потфасцикла",
    "Secure https://" : "Сигурни https://",
    "Dropbox" : "Dropbox",
    "Host" : "Домаћин",
    "Secure ftps://" : "Сигурни ftps://",
    "Local" : "локална",
    "Location" : "Локација",
    "ownCloud" : "оунКлауд",
    "SFTP with secret key login" : "СФТП са пријавом помоћу тајног кључа",
    "Share" : "Дели",
    "SMB / CIFS using OC login" : "СМБ/ЦИФС користећи оунКлауд пријаву",
    "Username as share" : "Корисничко име као дељење",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "<b>Note:</b> " : "<b>Напомена:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> cURL подршка за ПХП није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> ФТП подршка за ПХП није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> „%s“ није инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "No external storage configured" : "Нема подешеног спољашњег складишта",
    "You can add external storages in the personal settings" : "Можете додати спољна складишта у вашим личним подешавањима",
    "Name" : "Назив",
    "Storage type" : "Тип складишта",
    "Scope" : "Распон",
    "External Storage" : "Спољашње складиште",
    "Folder name" : "Назив фасцикле",
    "Configuration" : "Подешавање",
    "Available for" : "Доступно за",
    "Advanced settings" : "Напредне поставке",
    "Delete" : "Обриши",
    "Add storage" : "Додај складиште",
    "Enable User External Storage" : "Укључи корисничко спољашње складиште",
    "Allow users to mount the following external storage" : "Дозволи корисницима да монтирају следећа спољашња складишта"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sr.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Корак 1 није успео. Изузетак: %s",
    "Step 2 failed. Exception: %s" : "Корак 2 није успео. Изузетак: %s",
    "External storage" : "Спољашње складиште",
    "Storage with id \"%i\" not found" : "Складиште са идентификацијом \"%i\" није пронађено",
    "Invalid mount point" : "Неисправна тачка монтирања",
    "Invalid storage backend \"%s\"" : "Неисправна позадина складишта „%s“",
    "Personal" : "Лично",
    "System" : "Систем",
    "Grant access" : "Одобри приступ",
    "Access granted" : "Приступ одобрен",
    "Generate keys" : "Генериши кључеве",
    "Error generating key pair" : "Грешка при генерисању пара кључева",
    "Enable encryption" : "Укључи шифровање",
    "Enable previews" : "Укључи прегледе",
    "Check for changes" : "Провери измене",
    "Never" : "никад",
    "Once every direct access" : "једном при сваком директном приступу",
    "All users. Type to select user or group." : "Сви корисници. Куцајте за избор корисника или групе.",
    "(group)" : "(група)",
    "Saved" : "Сачувано",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Save" : "Сачувај",
    "None" : "Ништа",
    "App key" : "Кључ апликације",
    "App secret" : "Тајна апликације",
    "Client ID" : "ИД клијента",
    "Client secret" : "Тајна клијента",
    "API key" : "API кључ",
    "Public key" : "Јавни кључ",
    "Amazon S3" : "Амазон С3",
    "Bucket" : "Канта",
    "Hostname" : "Име домаћина",
    "Port" : "Порт",
    "Region" : "Регија",
    "Enable SSL" : "Омогући ССЛ",
    "Enable Path Style" : "Омогући стил путање",
    "WebDAV" : "ВебДАВ",
    "URL" : "УРЛ",
    "Remote subfolder" : "Удаљена потфасцикла",
    "Secure https://" : "Сигурни https://",
    "Dropbox" : "Dropbox",
    "Host" : "Домаћин",
    "Secure ftps://" : "Сигурни ftps://",
    "Local" : "локална",
    "Location" : "Локација",
    "ownCloud" : "оунКлауд",
    "SFTP with secret key login" : "СФТП са пријавом помоћу тајног кључа",
    "Share" : "Дели",
    "SMB / CIFS using OC login" : "СМБ/ЦИФС користећи оунКлауд пријаву",
    "Username as share" : "Корисничко име као дељење",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "<b>Note:</b> " : "<b>Напомена:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> cURL подршка за ПХП није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> ФТП подршка за ПХП није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> „%s“ није инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "No external storage configured" : "Нема подешеног спољашњег складишта",
    "You can add external storages in the personal settings" : "Можете додати спољна складишта у вашим личним подешавањима",
    "Name" : "Назив",
    "Storage type" : "Тип складишта",
    "Scope" : "Распон",
    "External Storage" : "Спољашње складиште",
    "Folder name" : "Назив фасцикле",
    "Configuration" : "Подешавање",
    "Available for" : "Доступно за",
    "Add storage" : "Додај складиште",
    "Advanced settings" : "Напредне поставке",
    "Delete" : "Обриши",
    "Allow users to mount the following external storage" : "Дозволи корисницима да монтирају следећа спољашња складишта"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
